@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -222,11 +222,18 @@ class Debugger2AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import debugger_v2
 
-            def sample_set_breakpoint():
+            async def sample_set_breakpoint():
                 # Create a client
-                client = debugger_v2.Debugger2Client()
+                client = debugger_v2.Debugger2AsyncClient()
 
                 # Initialize request argument(s)
                 request = debugger_v2.SetBreakpointRequest(
@@ -235,7 +242,7 @@ class Debugger2AsyncClient:
                 )
 
                 # Make the request
-                response = client.set_breakpoint(request=request)
+                response = await client.set_breakpoint(request=request)
 
                 # Handle the response
                 print(response)
@@ -304,8 +311,21 @@ class Debugger2AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("debuggee_id", request.debuggee_id),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -325,11 +345,18 @@ class Debugger2AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import debugger_v2
 
-            def sample_get_breakpoint():
+            async def sample_get_breakpoint():
                 # Create a client
-                client = debugger_v2.Debugger2Client()
+                client = debugger_v2.Debugger2AsyncClient()
 
                 # Initialize request argument(s)
                 request = debugger_v2.GetBreakpointRequest(
@@ -339,7 +366,7 @@ class Debugger2AsyncClient:
                 )
 
                 # Make the request
-                response = client.get_breakpoint(request=request)
+                response = await client.get_breakpoint(request=request)
 
                 # Handle the response
                 print(response)
@@ -421,8 +448,24 @@ class Debugger2AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("debuggee_id", request.debuggee_id),
+                    ("breakpoint_id", request.breakpoint_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -442,11 +485,18 @@ class Debugger2AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import debugger_v2
 
-            def sample_delete_breakpoint():
+            async def sample_delete_breakpoint():
                 # Create a client
-                client = debugger_v2.Debugger2Client()
+                client = debugger_v2.Debugger2AsyncClient()
 
                 # Initialize request argument(s)
                 request = debugger_v2.DeleteBreakpointRequest(
@@ -456,7 +506,7 @@ class Debugger2AsyncClient:
                 )
 
                 # Make the request
-                client.delete_breakpoint(request=request)
+                await client.delete_breakpoint(request=request)
 
         Args:
             request (Union[google.cloud.debugger_v2.types.DeleteBreakpointRequest, dict]):
@@ -528,9 +578,23 @@ class Debugger2AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("debuggee_id", request.debuggee_id),
+                    ("breakpoint_id", request.breakpoint_id),
+                )
+            ),
+        )
+
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def list_breakpoints(
@@ -547,11 +611,18 @@ class Debugger2AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import debugger_v2
 
-            def sample_list_breakpoints():
+            async def sample_list_breakpoints():
                 # Create a client
-                client = debugger_v2.Debugger2Client()
+                client = debugger_v2.Debugger2AsyncClient()
 
                 # Initialize request argument(s)
                 request = debugger_v2.ListBreakpointsRequest(
@@ -560,7 +631,7 @@ class Debugger2AsyncClient:
                 )
 
                 # Make the request
-                response = client.list_breakpoints(request=request)
+                response = await client.list_breakpoints(request=request)
 
                 # Handle the response
                 print(response)
@@ -630,8 +701,21 @@ class Debugger2AsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("debuggee_id", request.debuggee_id),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -650,11 +734,18 @@ class Debugger2AsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import debugger_v2
 
-            def sample_list_debuggees():
+            async def sample_list_debuggees():
                 # Create a client
-                client = debugger_v2.Debugger2Client()
+                client = debugger_v2.Debugger2AsyncClient()
 
                 # Initialize request argument(s)
                 request = debugger_v2.ListDebuggeesRequest(
@@ -663,7 +754,7 @@ class Debugger2AsyncClient:
                 )
 
                 # Make the request
-                response = client.list_debuggees(request=request)
+                response = await client.list_debuggees(request=request)
 
                 # Handle the response
                 print(response)
@@ -734,7 +825,12 @@ class Debugger2AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
